@@ -15,7 +15,7 @@
 namespace PolkitQt1
 {
 
-class Subject::Data : public QSharedData
+class Q_DECL_HIDDEN Subject::Data : public QSharedData
 {
 public:
     Data()
@@ -39,13 +39,11 @@ public:
 Subject::Subject()
         : d(new Data)
 {
-    g_type_init();
 }
 
 Subject::Subject(PolkitSubject *subject)
         : d(new Data)
 {
-    g_type_init();
     d->subject = subject;
     
     if (d->subject != nullptr) {
@@ -95,9 +93,6 @@ QString Subject::toString() const
 
 Subject Subject::fromString(const QString &string)
 {
-    // should be in polkit library!!! but for strange reason it's necessary to have it here
-    g_type_init();
-
     Subject subject;
     GError *error = nullptr;
     subject.d->subject = polkit_subject_from_string(string.toUtf8().data(), &error);
